Diagnostic

Struct Diagnostic 

#[repr(C)]
pub struct Diagnostic { pub level: ErrorLevel, pub message: DiagnosticMessage, pub loc: Loc, }
Diagnostic message that comes from the parser when there’s an error or warning

Fields

level: ErrorLevel

Level of the diagnostic (error or warnings)

message: DiagnosticMessage

Message of the diagnostic

loc: Loc

Location of the diagnostic

Implementations

Source

impl Diagnostic

pub fn render_message(&self) -> String

Returns rendered message

pub fn render(&self, input: &DecodedInput) -> Option<String>

Renders all data into a single String, produces an output like:

(test.rb):1:5: error: unexpected END_OF_INPUT
(test.rb):1: foo++
(test.rb):1:      ^
pub fn is_warning(&self) -> bool

Returns true if level of the diagnostic is Warning

pub fn is_error(&self) -> bool

Returns true if level of the diagnostic is Error