Loc

Struct Loc 

#[repr(C)]
pub struct Loc { pub begin: usize, pub end: usize, }
Representation of any location in the given input

Fields

begin: usize

Begin of the Loc range

end: usize

End of the Loc range

Implementations

Source

impl Loc

pub fn to_range(&self) -> Range<usize>

Converts location to a range

pub fn size(&self) -> usize

Returns size of the Loc (i.e. end - begin)

pub fn with_begin(&self, begin: usize) -> Loc

Returns a new Loc with given begin and current end

pub fn with_end(&self, end: usize) -> Loc

Returns a new Loc with given end and current begin

pub fn adjust_begin(&self, delta: i32) -> Loc

Adds given delta to begin

pub fn adjust_end(&self, d: i32) -> Loc

Adds given delta to end

pub fn resize(&self, new_size: usize) -> Loc

Returns a new Loc with the same begin, but adjusted end, so that its size is equal to given new_size

pub fn join(&self, other: &Loc) -> Loc

Joins two Locs by choosing min(begin) + max(end)

pub fn maybe_join(&self, other: &Option<Loc>) -> Loc

pub fn is_empty(&self) -> bool

Returns true if Loc is empty (i.e. begin == end)

pub fn print(&self, name: &str)